# APIs for Windows 32-bit advapi library.
# Format:  rettype, retname, callconv, exactname, arglist(type, name)
#          arglist type is one of ['int', 'void *']
#          arglist name is one of [None, 'funcptr', 'obj', 'ptr']

api_defs = {
    'advapi32.main_entry':( 'int', None, 'stdcall', 'advapi32.main_entry', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.a_shafinal':( 'int', None, 'stdcall', 'advapi32.A_SHAFinal', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.a_shainit':( 'int', None, 'stdcall', 'advapi32.A_SHAInit', (('void *', 'ptr'),) ),
    'advapi32.a_shaupdate':( 'int', None, 'stdcall', 'advapi32.A_SHAUpdate', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.abortsystemshutdowna':( 'int', None, 'stdcall', 'advapi32.AbortSystemShutdownA', ( ('int', None),) ),
    'advapi32.abortsystemshutdownw':( 'int', None, 'stdcall', 'advapi32.AbortSystemShutdownW', ( ('void *', 'ptr'),) ),
    'advapi32.accesscheck':( 'int', None, 'stdcall', 'advapi32.AccessCheck', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.accesscheckandauditalarma':( 'int', None, 'stdcall', 'advapi32.AccessCheckAndAuditAlarmA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckandauditalarmw':( 'int', None, 'stdcall', 'advapi32.AccessCheckAndAuditAlarmW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytype':( 'int', None, 'stdcall', 'advapi32.AccessCheckByType', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytypeandauditalarma':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeAndAuditAlarmA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytypeandauditalarmw':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeAndAuditAlarmW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytyperesultlist':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeResultList', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytyperesultlistandauditalarma':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeResultListAndAuditAlarmA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytyperesultlistandauditalarmbyhandlea':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeResultListAndAuditAlarmByHandleA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytyperesultlistandauditalarmbyhandlew':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeResultListAndAuditAlarmByHandleW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.accesscheckbytyperesultlistandauditalarmw':( 'int', None, 'stdcall', 'advapi32.AccessCheckByTypeResultListAndAuditAlarmW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addaccessallowedace':( 'int', None, 'stdcall', 'advapi32.AddAccessAllowedAce', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addaccessallowedaceex':( 'int', None, 'stdcall', 'advapi32.AddAccessAllowedAceEx', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.addaccessallowedobjectace':( 'int', None, 'stdcall', 'advapi32.AddAccessAllowedObjectAce', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.addaccessdeniedace':( 'int', None, 'stdcall', 'advapi32.AddAccessDeniedAce', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addaccessdeniedaceex':( 'int', None, 'stdcall', 'advapi32.AddAccessDeniedAceEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addaccessdeniedobjectace':( 'int', None, 'stdcall', 'advapi32.AddAccessDeniedObjectAce', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.addace':( 'int', None, 'bfastcall', 'advapi32.AddAce', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addauditaccessace':( 'int', None, 'stdcall', 'advapi32.AddAuditAccessAce', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addauditaccessaceex':( 'int', None, 'stdcall', 'advapi32.AddAuditAccessAceEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.addauditaccessobjectace':( 'int', None, 'stdcall', 'advapi32.AddAuditAccessObjectAce', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.adduserstoencryptedfile':( 'int', None, 'stdcall', 'advapi32.AddUsersToEncryptedFile', (('int', None), ('int', None)) ),
    'advapi32.adjusttokengroups':( 'int', None, 'stdcall', 'advapi32.AdjustTokenGroups', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.adjusttokenprivileges':( 'int', None, 'stdcall', 'advapi32.AdjustTokenPrivileges', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.allocateandinitializesid':( 'int', None, 'stdcall', 'advapi32.AllocateAndInitializeSid', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.allocatelocallyuniqueid':( 'int', None, 'stdcall', 'advapi32.AllocateLocallyUniqueId', (('int', None),) ),
    'advapi32.areallaccessesgranted':( 'int', None, 'stdcall', 'advapi32.AreAllAccessesGranted', (('int', None), ('int', None)) ),
    'advapi32.areanyaccessesgranted':( 'int', None, 'stdcall', 'advapi32.AreAnyAccessesGranted', (('int', None), ('int', None)) ),
    'advapi32.backupeventloga':( 'int', None, 'stdcall', 'advapi32.BackupEventLogA', (('int', None), ('int', None)) ),
    'advapi32.backupeventlogw':( 'int', None, 'stdcall', 'advapi32.BackupEventLogW', (('int', None), ('int', None)) ),
    'advapi32.buildexplicitaccesswithnamea':( 'int', None, 'stdcall', 'advapi32.BuildExplicitAccessWithNameA', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildexplicitaccesswithnamew':( 'int', None, 'stdcall', 'advapi32.BuildExplicitAccessWithNameW', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildimpersonateexplicitaccesswithnamea':( 'int', None, 'stdcall', 'advapi32.BuildImpersonateExplicitAccessWithNameA', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildimpersonateexplicitaccesswithnamew':( 'int', None, 'stdcall', 'advapi32.BuildImpersonateExplicitAccessWithNameW', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildimpersonatetrusteea':( 'int', None, 'stdcall', 'advapi32.BuildImpersonateTrusteeA', (('int', None), ('int', None)) ),
    'advapi32.buildimpersonatetrusteew':( 'int', None, 'stdcall', 'advapi32.BuildImpersonateTrusteeW', (('int', None), ('int', None)) ),
    'advapi32.buildsecuritydescriptora':( 'int', None, 'stdcall', 'advapi32.BuildSecurityDescriptorA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.buildsecuritydescriptorw':( 'int', None, 'stdcall', 'advapi32.BuildSecurityDescriptorW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.buildtrusteewithnamea':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithNameA', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.buildtrusteewithnamew':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithNameW', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.buildtrusteewithobjectsandnamea':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithObjectsAndNameA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildtrusteewithobjectsandnamew':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithObjectsAndNameW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildtrusteewithobjectsandsida':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithObjectsAndSidA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildtrusteewithobjectsandsidw':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithObjectsAndSidW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.buildtrusteewithsida':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithSidA', (('int', None), ('int', None)) ),
    'advapi32.buildtrusteewithsidw':( 'int', None, 'stdcall', 'advapi32.BuildTrusteeWithSidW', (('int', None), ('int', None)) ),
    'advapi32.canceloverlappedaccess':( 'int', None, 'stdcall', 'advapi32.CancelOverlappedAccess', (('int', None),) ),
    'advapi32.changeserviceconfig2a':( 'int', None, 'stdcall', 'advapi32.ChangeServiceConfig2A', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.changeserviceconfig2w':( 'int', None, 'stdcall', 'advapi32.ChangeServiceConfig2W', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.changeserviceconfiga':( 'int', None, 'stdcall', 'advapi32.ChangeServiceConfigA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.changeserviceconfigw':( 'int', None, 'stdcall', 'advapi32.ChangeServiceConfigW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.checktokenmembership':( 'int', None, 'stdcall', 'advapi32.CheckTokenMembership', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.cleareventloga':( 'int', None, 'stdcall', 'advapi32.ClearEventLogA', (('int', None), ('int', None)) ),
    'advapi32.cleareventlogw':( 'int', None, 'stdcall', 'advapi32.ClearEventLogW', (('int', None), ('int', None)) ),
    'advapi32.closecodeauthzlevel':( 'int', None, 'stdcall', 'advapi32.CloseCodeAuthzLevel', (('int', None),) ),
    'advapi32.closeencryptedfileraw':( 'int', None, 'cdecl', 'advapi32.CloseEncryptedFileRaw', () ),
    'advapi32.closeeventlog':( 'int', None, 'stdcall', 'advapi32.CloseEventLog', (('int', None),) ),
    'advapi32.closeservicehandle':( 'int', None, 'stdcall', 'advapi32.CloseServiceHandle', (('int', None),) ),
    'advapi32.closetrace':( 'int', None, 'stdcall', 'advapi32.CloseTrace', (('int', None), ('int', None)) ),
    'advapi32.commandlinefrommsidescriptor':( 'int', None, 'stdcall', 'advapi32.CommandLineFromMsiDescriptor', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.computeaccesstokenfromcodeauthzlevel':( 'int', None, 'stdcall', 'advapi32.ComputeAccessTokenFromCodeAuthzLevel', ( ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.controlservice':( 'int', None, 'stdcall', 'advapi32.ControlService', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.controltracea':( 'int', None, 'stdcall', 'advapi32.ControlTraceA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.controltracew':( 'int', None, 'stdcall', 'advapi32.ControlTraceW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.convertaccesstosecuritydescriptora':( 'int', None, 'stdcall', 'advapi32.ConvertAccessToSecurityDescriptorA', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertaccesstosecuritydescriptorw':( 'int', None, 'stdcall', 'advapi32.ConvertAccessToSecurityDescriptorW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertsdtostringsdrootdomaina':( 'int', None, 'stdcall', 'advapi32.ConvertSDToStringSDRootDomainA', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertsdtostringsdrootdomainw':( 'int', None, 'stdcall', 'advapi32.ConvertSDToStringSDRootDomainW', ( ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.convertsecuritydescriptortoaccessa':( 'int', None, 'stdcall', 'advapi32.ConvertSecurityDescriptorToAccessA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.convertsecuritydescriptortoaccessnameda':( 'int', None, 'stdcall', 'advapi32.ConvertSecurityDescriptorToAccessNamedA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.convertsecuritydescriptortoaccessnamedw':( 'int', None, 'stdcall', 'advapi32.ConvertSecurityDescriptorToAccessNamedW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertsecuritydescriptortoaccessw':( 'int', None, 'stdcall', 'advapi32.ConvertSecurityDescriptorToAccessW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertsecuritydescriptortostringsecuritydescriptora':( 'int', None, 'stdcall', 'advapi32.ConvertSecurityDescriptorToStringSecurityDescriptorA', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertsecuritydescriptortostringsecuritydescriptorw':( 'int', None, 'stdcall', 'advapi32.ConvertSecurityDescriptorToStringSecurityDescriptorW', ( ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.convertsidtostringsida':( 'int', None, 'stdcall', 'advapi32.ConvertSidToStringSidA', ( ('int', None), ('int', None)) ),
    'advapi32.convertsidtostringsidw':( 'int', None, 'stdcall', 'advapi32.ConvertSidToStringSidW', ( ('int', None), ('void *', 'ptr')) ),
    'advapi32.convertstringsdtosddomaina':( 'int', None, 'stdcall', 'advapi32.ConvertStringSDToSDDomainA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertstringsdtosddomainw':( 'int', None, 'stdcall', 'advapi32.ConvertStringSDToSDDomainW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertstringsdtosdrootdomaina':( 'int', None, 'stdcall', 'advapi32.ConvertStringSDToSDRootDomainA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertstringsdtosdrootdomainw':( 'int', None, 'stdcall', 'advapi32.ConvertStringSDToSDRootDomainW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertstringsecuritydescriptortosecuritydescriptora':( 'int', None, 'stdcall', 'advapi32.ConvertStringSecurityDescriptorToSecurityDescriptorA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertstringsecuritydescriptortosecuritydescriptorw':( 'int', None, 'stdcall', 'advapi32.ConvertStringSecurityDescriptorToSecurityDescriptorW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.convertstringsidtosida':( 'int', None, 'stdcall', 'advapi32.ConvertStringSidToSidA', (('int', None), ('int', None)) ),
    'advapi32.convertstringsidtosidw':( 'int', None, 'stdcall', 'advapi32.ConvertStringSidToSidW', (('int', None), ('void *', 'ptr')) ),
    'advapi32.converttoautoinheritprivateobjectsecurity':( 'int', None, 'stdcall', 'advapi32.ConvertToAutoInheritPrivateObjectSecurity', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.copysid':( 'int', None, 'stdcall', 'advapi32.CopySid', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.createcodeauthzlevel':( 'int', None, 'stdcall', 'advapi32.CreateCodeAuthzLevel', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createprivateobjectsecurity':( 'int', None, 'stdcall', 'advapi32.CreatePrivateObjectSecurity', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createprivateobjectsecurityex':( 'int', None, 'stdcall', 'advapi32.CreatePrivateObjectSecurityEx', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.createprivateobjectsecuritywithmultipleinheritance':( 'int', None, 'stdcall', 'advapi32.CreatePrivateObjectSecurityWithMultipleInheritance', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createprocessasusera':( 'int', None, 'stdcall', 'advapi32.CreateProcessAsUserA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createprocessasusersecure':( 'int', None, 'cdecl', 'advapi32.CreateProcessAsUserSecure', () ),
    'advapi32.createprocessasuserw':( 'int', None, 'stdcall', 'advapi32.CreateProcessAsUserW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createprocesswithlogonw':( 'int', None, 'stdcall', 'advapi32.CreateProcessWithLogonW', (('int', None), ('int', None), ('int', None), ('int', None), ('StringW', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createrestrictedtoken':( 'int', None, 'stdcall', 'advapi32.CreateRestrictedToken', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.createservicea':( 'int', None, 'stdcall', 'advapi32.CreateServiceA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createservicew':( 'int', None, 'stdcall', 'advapi32.CreateServiceW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.createtraceinstanceid':( 'int', None, 'stdcall', 'advapi32.CreateTraceInstanceId', (('int', None), ('int', None)) ),
    'advapi32.createwellknownsid':( 'int', None, 'stdcall', 'advapi32.CreateWellKnownSid', ( ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.creddeletea':( 'int', None, 'stdcall', 'advapi32.CredDeleteA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.creddeletew':( 'int', None, 'stdcall', 'advapi32.CredDeleteW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.credenumeratea':( 'int', None, 'stdcall', 'advapi32.CredEnumerateA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.credenumeratew':( 'int', None, 'stdcall', 'advapi32.CredEnumerateW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.credfree':( 'int', None, 'cdecl', 'advapi32.CredFree', () ),
    'advapi32.credgetsessiontypes':( 'int', None, 'stdcall', 'advapi32.CredGetSessionTypes', (('int', None), ('int', None)) ),
    'advapi32.credgettargetinfoa':( 'int', None, 'stdcall', 'advapi32.CredGetTargetInfoA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.credgettargetinfow':( 'int', None, 'stdcall', 'advapi32.CredGetTargetInfoW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.credismarshaledcredentiala':( 'int', None, 'stdcall', 'advapi32.CredIsMarshaledCredentialA', (('int', None),) ),
    'advapi32.credismarshaledcredentialw':( 'int', None, 'stdcall', 'advapi32.CredIsMarshaledCredentialW', (('int', None),) ),
    'advapi32.credmarshalcredentiala':( 'int', None, 'stdcall', 'advapi32.CredMarshalCredentialA', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.credmarshalcredentialw':( 'int', None, 'stdcall', 'advapi32.CredMarshalCredentialW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.credprofileloaded':( 'int', None, 'cdecl', 'advapi32.CredProfileLoaded', () ),
    'advapi32.credreada':( 'int', None, 'stdcall', 'advapi32.CredReadA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.credreaddomaincredentialsa':( 'int', None, 'stdcall', 'advapi32.CredReadDomainCredentialsA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.credreaddomaincredentialsw':( 'int', None, 'stdcall', 'advapi32.CredReadDomainCredentialsW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.credreadw':( 'int', None, 'stdcall', 'advapi32.CredReadW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.credrenamea':( 'int', None, 'stdcall', 'advapi32.CredRenameA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.credrenamew':( 'int', None, 'stdcall', 'advapi32.CredRenameW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.credunmarshalcredentiala':( 'int', None, 'stdcall', 'advapi32.CredUnmarshalCredentialA', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.credunmarshalcredentialw':( 'int', None, 'stdcall', 'advapi32.CredUnmarshalCredentialW', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.credwritea':( 'int', None, 'stdcall', 'advapi32.CredWriteA', (('int', None), ('int', None)) ),
    'advapi32.credwritedomaincredentialsa':( 'int', None, 'stdcall', 'advapi32.CredWriteDomainCredentialsA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.credwritedomaincredentialsw':( 'int', None, 'stdcall', 'advapi32.CredWriteDomainCredentialsW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.credwritew':( 'int', None, 'stdcall', 'advapi32.CredWriteW', (('int', None), ('int', None)) ),
    'advapi32.credpconvertcredential':( 'int', None, 'stdcall', 'advapi32.CredpConvertCredential', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.credpconverttargetinfo':( 'int', None, 'stdcall', 'advapi32.CredpConvertTargetInfo', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.credpdecodecredential':( 'int', None, 'stdcall', 'advapi32.CredpDecodeCredential', (('int', None),) ),
    'advapi32.credpencodecredential':( 'int', None, 'stdcall', 'advapi32.CredpEncodeCredential', (('int', None),) ),
    'advapi32.cryptacquirecontexta':( 'int', None, 'stdcall', 'advapi32.CryptAcquireContextA', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptacquirecontextw':( 'int', None, 'stdcall', 'advapi32.CryptAcquireContextW', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptcontextaddref':( 'int', None, 'stdcall', 'advapi32.CryptContextAddRef', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptcreatehash':( 'int', None, 'stdcall', 'advapi32.CryptCreateHash', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.cryptdecrypt':( 'int', None, 'stdcall', 'advapi32.CryptDecrypt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptderivekey':( 'int', None, 'stdcall', 'advapi32.CryptDeriveKey', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptdestroyhash':( 'int', None, 'stdcall', 'advapi32.CryptDestroyHash', (('void *', 'ptr'),) ),
    'advapi32.cryptdestroykey':( 'int', None, 'stdcall', 'advapi32.CryptDestroyKey', (('void *', 'ptr'),) ),
    'advapi32.cryptduplicatehash':( 'int', None, 'stdcall', 'advapi32.CryptDuplicateHash', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptduplicatekey':( 'int', None, 'stdcall', 'advapi32.CryptDuplicateKey', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptencrypt':( 'int', None, 'stdcall', 'advapi32.CryptEncrypt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptenumprovidertypesa':( 'int', None, 'stdcall', 'advapi32.CryptEnumProviderTypesA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.cryptenumprovidertypesw':( 'int', None, 'stdcall', 'advapi32.CryptEnumProviderTypesW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptenumprovidersa':( 'int', None, 'stdcall', 'advapi32.CryptEnumProvidersA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.cryptenumprovidersw':( 'int', None, 'stdcall', 'advapi32.CryptEnumProvidersW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptexportkey':( 'int', None, 'stdcall', 'advapi32.CryptExportKey', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptgenkey':( 'int', None, 'stdcall', 'advapi32.CryptGenKey', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptgenrandom':( 'int', None, 'stdcall', 'advapi32.CryptGenRandom', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptgetdefaultprovidera':( 'int', None, 'stdcall', 'advapi32.CryptGetDefaultProviderA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.cryptgetdefaultproviderw':( 'int', None, 'stdcall', 'advapi32.CryptGetDefaultProviderW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptgethashparam':( 'int', None, 'stdcall', 'advapi32.CryptGetHashParam', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.cryptgetkeyparam':( 'int', None, 'stdcall', 'advapi32.CryptGetKeyParam', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptgetprovparam':( 'int', None, 'stdcall', 'advapi32.CryptGetProvParam', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptgetuserkey':( 'int', None, 'stdcall', 'advapi32.CryptGetUserKey', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.crypthashdata':( 'int', None, 'stdcall', 'advapi32.CryptHashData', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.crypthashsessionkey':( 'int', None, 'stdcall', 'advapi32.CryptHashSessionKey', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptimportkey':( 'int', None, 'stdcall', 'advapi32.CryptImportKey', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptreleasecontext':( 'int', None, 'stdcall', 'advapi32.CryptReleaseContext', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.cryptsethashparam':( 'int', None, 'stdcall', 'advapi32.CryptSetHashParam', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptsetkeyparam':( 'int', None, 'stdcall', 'advapi32.CryptSetKeyParam', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptsetprovparam':( 'int', None, 'stdcall', 'advapi32.CryptSetProvParam', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptsetprovidera':( 'int', None, 'stdcall', 'advapi32.CryptSetProviderA', (('int', None), ('int', None)) ),
    'advapi32.cryptsetproviderexa':( 'int', None, 'stdcall', 'advapi32.CryptSetProviderExA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptsetproviderexw':( 'int', None, 'stdcall', 'advapi32.CryptSetProviderExW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptsetproviderw':( 'int', None, 'stdcall', 'advapi32.CryptSetProviderW', (('int', None), ('int', None)) ),
    'advapi32.cryptsignhasha':( 'int', None, 'stdcall', 'advapi32.CryptSignHashA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptsignhashw':( 'int', None, 'stdcall', 'advapi32.CryptSignHashW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptverifysignaturea':( 'int', None, 'stdcall', 'advapi32.CryptVerifySignatureA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.cryptverifysignaturew':( 'int', None, 'stdcall', 'advapi32.CryptVerifySignatureW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.decryptfilea':( 'int', None, 'stdcall', 'advapi32.DecryptFileA', (('int', None), ('int', None)) ),
    'advapi32.decryptfilew':( 'int', None, 'stdcall', 'advapi32.DecryptFileW', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.deleteace':( 'int', None, 'bfastcall', 'advapi32.DeleteAce', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.deleteservice':( 'int', None, 'stdcall', 'advapi32.DeleteService', (('int', None),) ),
    'advapi32.deregistereventsource':( 'int', None, 'stdcall', 'advapi32.DeregisterEventSource', (('int', None),) ),
    'advapi32.destroyprivateobjectsecurity':( 'int', None, 'stdcall', 'advapi32.DestroyPrivateObjectSecurity', (('void *', 'ptr'),) ),
    'advapi32.duplicateencryptioninfofile':( 'int', None, 'stdcall', 'advapi32.DuplicateEncryptionInfoFile', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.duplicatetoken':( 'int', None, 'stdcall', 'advapi32.DuplicateToken', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.duplicatetokenex':( 'int', None, 'stdcall', 'advapi32.DuplicateTokenEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.elfbackupeventlogfilea':( 'int', None, 'stdcall', 'advapi32.ElfBackupEventLogFileA', (('int', None), ('int', None)) ),
    'advapi32.elfbackupeventlogfilew':( 'int', None, 'stdcall', 'advapi32.ElfBackupEventLogFileW', (('int', None), ('void *', 'ptr')) ),
    'advapi32.elfchangenotify':( 'int', None, 'stdcall', 'advapi32.ElfChangeNotify', (('int', None), ('int', None)) ),
    'advapi32.elfcleareventlogfilea':( 'int', None, 'stdcall', 'advapi32.ElfClearEventLogFileA', (('int', None), ('int', None)) ),
    'advapi32.elfcleareventlogfilew':( 'int', None, 'stdcall', 'advapi32.ElfClearEventLogFileW', (('int', None), ('void *', 'ptr')) ),
    'advapi32.elfcloseeventlog':( 'int', None, 'stdcall', 'advapi32.ElfCloseEventLog', (('int', None),) ),
    'advapi32.elfderegistereventsource':( 'int', None, 'stdcall', 'advapi32.ElfDeregisterEventSource', (('int', None),) ),
    'advapi32.elfflusheventlog':( 'int', None, 'stdcall', 'advapi32.ElfFlushEventLog', (('int', None),) ),
    'advapi32.elfnumberofrecords':( 'int', None, 'stdcall', 'advapi32.ElfNumberOfRecords', (('int', None), ('int', None)) ),
    'advapi32.elfoldestrecord':( 'int', None, 'stdcall', 'advapi32.ElfOldestRecord', (('int', None), ('int', None)) ),
    'advapi32.elfopenbackupeventloga':( 'int', None, 'stdcall', 'advapi32.ElfOpenBackupEventLogA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.elfopenbackupeventlogw':( 'int', None, 'stdcall', 'advapi32.ElfOpenBackupEventLogW', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.elfopeneventloga':( 'int', None, 'stdcall', 'advapi32.ElfOpenEventLogA', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.elfopeneventlogw':( 'int', None, 'stdcall', 'advapi32.ElfOpenEventLogW', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.elfreadeventloga':( 'int', None, 'stdcall', 'advapi32.ElfReadEventLogA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.elfreadeventlogw':( 'int', None, 'stdcall', 'advapi32.ElfReadEventLogW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.elfregistereventsourcea':( 'int', None, 'stdcall', 'advapi32.ElfRegisterEventSourceA', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.elfregistereventsourcew':( 'int', None, 'stdcall', 'advapi32.ElfRegisterEventSourceW', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.elfreporteventa':( 'int', None, 'stdcall', 'advapi32.ElfReportEventA', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.elfreporteventw':( 'int', None, 'stdcall', 'advapi32.ElfReportEventW', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enabletrace':( 'int', None, 'stdcall', 'advapi32.EnableTrace', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.encryptfilea':( 'int', None, 'stdcall', 'advapi32.EncryptFileA', (('int', None),) ),
    'advapi32.encryptfilew':( 'int', None, 'stdcall', 'advapi32.EncryptFileW', (('void *', 'ptr'),) ),
    'advapi32.encryptedfilekeyinfo':( 'int', None, 'stdcall', 'advapi32.EncryptedFileKeyInfo', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.encryptiondisable':( 'int', None, 'stdcall', 'advapi32.EncryptionDisable', (('int', None), ('int', None)) ),
    'advapi32.enumdependentservicesa':( 'int', None, 'stdcall', 'advapi32.EnumDependentServicesA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enumdependentservicesw':( 'int', None, 'stdcall', 'advapi32.EnumDependentServicesW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enumservicegroupw':( 'int', None, 'stdcall', 'advapi32.EnumServiceGroupW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enumservicesstatusa':( 'int', None, 'stdcall', 'advapi32.EnumServicesStatusA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enumservicesstatusexa':( 'int', None, 'stdcall', 'advapi32.EnumServicesStatusExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enumservicesstatusexw':( 'int', None, 'stdcall', 'advapi32.EnumServicesStatusExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.enumservicesstatusw':( 'int', None, 'stdcall', 'advapi32.EnumServicesStatusW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.enumeratetraceguids':( 'int', None, 'stdcall', 'advapi32.EnumerateTraceGuids', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.equaldomainsid':( 'int', None, 'stdcall', 'advapi32.EqualDomainSid', ( ('int', None), ('int', None), ('int', None)) ),
    'advapi32.equalprefixsid':( 'int', None, 'stdcall', 'advapi32.EqualPrefixSid', (('int', None), ('int', None)) ),
    'advapi32.equalsid':( 'int', None, 'stdcall', 'advapi32.EqualSid', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.fileencryptionstatusa':( 'int', None, 'stdcall', 'advapi32.FileEncryptionStatusA', (('int', None), ('int', None)) ),
    'advapi32.fileencryptionstatusw':( 'int', None, 'stdcall', 'advapi32.FileEncryptionStatusW', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.findfirstfreeace':( 'int', None, 'stdcall', 'advapi32.FindFirstFreeAce', (('int', None), ('int', None)) ),
    'advapi32.flushtracea':( 'int', None, 'stdcall', 'advapi32.FlushTraceA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.flushtracew':( 'int', None, 'stdcall', 'advapi32.FlushTraceW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.freeencryptedfilekeyinfo':( 'int', None, 'stdcall', 'advapi32.FreeEncryptedFileKeyInfo', (('int', None),) ),
    'advapi32.freeencryptioncertificatehashlist':( 'int', None, 'stdcall', 'advapi32.FreeEncryptionCertificateHashList', (('int', None),) ),
    'advapi32.freeinheritedfromarray':( 'int', None, 'stdcall', 'advapi32.FreeInheritedFromArray', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.freesid':( 'int', None, 'cdecl', 'advapi32.FreeSid', () ),
    'advapi32.getaccesspermissionsforobjecta':( 'int', None, 'stdcall', 'advapi32.GetAccessPermissionsForObjectA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getaccesspermissionsforobjectw':( 'int', None, 'stdcall', 'advapi32.GetAccessPermissionsForObjectW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getace':( 'int', None, 'stdcall', 'advapi32.GetAce', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.getaclinformation':( 'int', None, 'bfastcall', 'advapi32.GetAclInformation', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getauditedpermissionsfromacla':( 'int', None, 'stdcall', 'advapi32.GetAuditedPermissionsFromAclA', ( ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getauditedpermissionsfromaclw':( 'int', None, 'stdcall', 'advapi32.GetAuditedPermissionsFromAclW', ( ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.getcurrenthwprofilea':( 'int', None, 'stdcall', 'advapi32.GetCurrentHwProfileA', (('int', None),) ),
    'advapi32.getcurrenthwprofilew':( 'int', None, 'stdcall', 'advapi32.GetCurrentHwProfileW', (('void *', 'ptr'),) ),
    'advapi32.geteffectiverightsfromacla':( 'int', None, 'stdcall', 'advapi32.GetEffectiveRightsFromAclA', ( ('int', None), ('int', None), ('int', None)) ),
    'advapi32.geteffectiverightsfromaclw':( 'int', None, 'stdcall', 'advapi32.GetEffectiveRightsFromAclW', ( ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.geteventloginformation':( 'int', None, 'stdcall', 'advapi32.GetEventLogInformation', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getexplicitentriesfromacla':( 'int', None, 'stdcall', 'advapi32.GetExplicitEntriesFromAclA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.getexplicitentriesfromaclw':( 'int', None, 'stdcall', 'advapi32.GetExplicitEntriesFromAclW', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getfilesecuritya':( 'int', None, 'stdcall', 'advapi32.GetFileSecurityA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getfilesecurityw':( 'int', None, 'stdcall', 'advapi32.GetFileSecurityW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getinformationcodeauthzlevelw':( 'int', None, 'stdcall', 'advapi32.GetInformationCodeAuthzLevelW', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.getinformationcodeauthzpolicyw':( 'int', None, 'stdcall', 'advapi32.GetInformationCodeAuthzPolicyW', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getinheritancesourcea':( 'int', None, 'stdcall', 'advapi32.GetInheritanceSourceA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getinheritancesourcew':( 'int', None, 'stdcall', 'advapi32.GetInheritanceSourceW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getkernelobjectsecurity':( 'int', None, 'stdcall', 'advapi32.GetKernelObjectSecurity', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getlengthsid':( 'int', None, 'cdecl', 'advapi32.GetLengthSid', () ),
    'advapi32.getlocalmanagedapplicationdata':( 'int', None, 'stdcall', 'advapi32.GetLocalManagedApplicationData', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.getlocalmanagedapplications':( 'int', None, 'stdcall', 'advapi32.GetLocalManagedApplications', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.getmanagedapplicationcategories':( 'int', None, 'stdcall', 'advapi32.GetManagedApplicationCategories', (('int', None), ('int', None)) ),
    'advapi32.getmanagedapplications':( 'int', None, 'stdcall', 'advapi32.GetManagedApplications', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getmultipletrusteea':( 'int', None, 'stdcall', 'advapi32.GetMultipleTrusteeA', (('int', None),) ),
    'advapi32.getmultipletrusteeoperationa':( 'int', None, 'stdcall', 'advapi32.GetMultipleTrusteeOperationA', (('int', None),) ),
    'advapi32.getmultipletrusteeoperationw':( 'int', None, 'stdcall', 'advapi32.GetMultipleTrusteeOperationW', (('int', None),) ),
    'advapi32.getmultipletrusteew':( 'int', None, 'stdcall', 'advapi32.GetMultipleTrusteeW', (('int', None),) ),
    'advapi32.getnamedsecurityinfoa':( 'int', None, 'stdcall', 'advapi32.GetNamedSecurityInfoA', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getnamedsecurityinfoexa':( 'int', None, 'stdcall', 'advapi32.GetNamedSecurityInfoExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getnamedsecurityinfoexw':( 'int', None, 'stdcall', 'advapi32.GetNamedSecurityInfoExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.getnamedsecurityinfow':( 'int', None, 'stdcall', 'advapi32.GetNamedSecurityInfoW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getnumberofeventlogrecords':( 'int', None, 'stdcall', 'advapi32.GetNumberOfEventLogRecords', (('int', None), ('int', None)) ),
    'advapi32.getoldesteventlogrecord':( 'int', None, 'stdcall', 'advapi32.GetOldestEventLogRecord', (('int', None), ('int', None)) ),
    'advapi32.getoverlappedaccessresults':( 'int', None, 'stdcall', 'advapi32.GetOverlappedAccessResults', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.getprivateobjectsecurity':( 'int', None, 'stdcall', 'advapi32.GetPrivateObjectSecurity', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getsecuritydescriptorcontrol':( 'int', None, 'stdcall', 'advapi32.GetSecurityDescriptorControl', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.getsecuritydescriptordacl':( 'int', None, 'stdcall', 'advapi32.GetSecurityDescriptorDacl', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getsecuritydescriptorgroup':( 'int', None, 'stdcall', 'advapi32.GetSecurityDescriptorGroup', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getsecuritydescriptorlength':( 'int', None, 'cdecl', 'advapi32.GetSecurityDescriptorLength', () ),
    'advapi32.getsecuritydescriptorowner':( 'int', None, 'stdcall', 'advapi32.GetSecurityDescriptorOwner', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getsecuritydescriptorrmcontrol':( 'int', None, 'stdcall', 'advapi32.GetSecurityDescriptorRMControl', (('int', None), ('int', None)) ),
    'advapi32.getsecuritydescriptorsacl':( 'int', None, 'stdcall', 'advapi32.GetSecurityDescriptorSacl', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getsecurityinfo':( 'int', None, 'stdcall', 'advapi32.GetSecurityInfo', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getsecurityinfoexa':( 'int', None, 'stdcall', 'advapi32.GetSecurityInfoExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getsecurityinfoexw':( 'int', None, 'stdcall', 'advapi32.GetSecurityInfoExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getservicedisplaynamea':( 'int', None, 'stdcall', 'advapi32.GetServiceDisplayNameA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getservicedisplaynamew':( 'int', None, 'stdcall', 'advapi32.GetServiceDisplayNameW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getservicekeynamea':( 'int', None, 'stdcall', 'advapi32.GetServiceKeyNameA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getservicekeynamew':( 'int', None, 'stdcall', 'advapi32.GetServiceKeyNameW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.getsididentifierauthority':( 'int', None, 'cdecl', 'advapi32.GetSidIdentifierAuthority', () ),
    'advapi32.getsidlengthrequired':( 'int', None, 'stdcall', 'advapi32.GetSidLengthRequired', (('int', None),) ),
    'advapi32.getsidsubauthority':( 'int', None, 'cdecl', 'advapi32.GetSidSubAuthority', () ),
    'advapi32.getsidsubauthoritycount':( 'int', None, 'cdecl', 'advapi32.GetSidSubAuthorityCount', () ),
    'advapi32.gettokeninformation':( 'int', None, 'stdcall', 'advapi32.GetTokenInformation', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.gettraceenableflags':( 'int', None, 'stdcall', 'advapi32.GetTraceEnableFlags', (('int', None), ('int', None)) ),
    'advapi32.gettraceenablelevel':( 'int', None, 'stdcall', 'advapi32.GetTraceEnableLevel', (('int', None), ('int', None)) ),
    'advapi32.gettraceloggerhandle':( 'int', None, 'stdcall', 'advapi32.GetTraceLoggerHandle', (('int', None),) ),
    'advapi32.gettrusteeforma':( 'int', None, 'stdcall', 'advapi32.GetTrusteeFormA', (('int', None),) ),
    'advapi32.gettrusteeformw':( 'int', None, 'stdcall', 'advapi32.GetTrusteeFormW', (('int', None),) ),
    'advapi32.gettrusteenamea':( 'int', None, 'stdcall', 'advapi32.GetTrusteeNameA', (('int', None),) ),
    'advapi32.gettrusteenamew':( 'int', None, 'stdcall', 'advapi32.GetTrusteeNameW', (('int', None),) ),
    'advapi32.gettrusteetypea':( 'int', None, 'stdcall', 'advapi32.GetTrusteeTypeA', (('int', None),) ),
    'advapi32.gettrusteetypew':( 'int', None, 'stdcall', 'advapi32.GetTrusteeTypeW', (('int', None),) ),
    'advapi32.getusernamea':( 'int', None, 'stdcall', 'advapi32.GetUserNameA', (('int', None), ('int', None)) ),
    'advapi32.getusernamew':( 'int', None, 'stdcall', 'advapi32.GetUserNameW', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.getwindowsaccountdomainsid':( 'int', None, 'stdcall', 'advapi32.GetWindowsAccountDomainSid', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.i_scgetcurrentgroupstatew':( 'int', None, 'stdcall', 'advapi32.I_ScGetCurrentGroupStateW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.i_scissecurityprocess':( 'int', None, 'cdecl', 'advapi32.I_ScIsSecurityProcess', () ),
    'advapi32.i_scpnpgetservicename':( 'int', None, 'stdcall', 'advapi32.I_ScPnPGetServiceName', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.i_scsendtsmessage':( 'int', None, 'stdcall', 'advapi32.I_ScSendTSMessage', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.i_scsetservicebitsa':( 'int', None, 'stdcall', 'advapi32.I_ScSetServiceBitsA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.i_scsetservicebitsw':( 'int', None, 'stdcall', 'advapi32.I_ScSetServiceBitsW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.identifycodeauthzlevelw':( 'int', None, 'stdcall', 'advapi32.IdentifyCodeAuthzLevelW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.impersonateanonymoustoken':( 'int', None, 'stdcall', 'advapi32.ImpersonateAnonymousToken', (('int', None),) ),
    'advapi32.impersonateloggedonuser':( 'int', None, 'stdcall', 'advapi32.ImpersonateLoggedOnUser', (('int', None),) ),
    'advapi32.impersonatenamedpipeclient':( 'int', None, 'stdcall', 'advapi32.ImpersonateNamedPipeClient', (('int', None),) ),
    'advapi32.impersonateself':( 'int', None, 'stdcall', 'advapi32.ImpersonateSelf', (('int', None),) ),
    'advapi32.initializeacl':( 'int', None, 'stdcall', 'advapi32.InitializeAcl', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.initializesecuritydescriptor':( 'int', None, 'stdcall', 'advapi32.InitializeSecurityDescriptor', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.initializesid':( 'int', None, 'stdcall', 'advapi32.InitializeSid', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.initiatesystemshutdowna':( 'int', None, 'stdcall', 'advapi32.InitiateSystemShutdownA', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.initiatesystemshutdownexa':( 'int', None, 'stdcall', 'advapi32.InitiateSystemShutdownExA', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.initiatesystemshutdownexw':( 'int', None, 'stdcall', 'advapi32.InitiateSystemShutdownExW', ( ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.initiatesystemshutdownw':( 'int', None, 'stdcall', 'advapi32.InitiateSystemShutdownW', ( ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.installapplication':( 'int', None, 'stdcall', 'advapi32.InstallApplication', (('int', None),) ),
    'advapi32.istextunicode':( 'int', None, 'stdcall', 'advapi32.IsTextUnicode', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.istokenrestricted':( 'int', None, 'stdcall', 'advapi32.IsTokenRestricted', ( ('int', None),) ),
    'advapi32.istokenuntrusted':( 'int', None, 'stdcall', 'advapi32.IsTokenUntrusted', (('int', None),) ),
    'advapi32.isvalidacl':( 'int', None, 'stdcall', 'advapi32.IsValidAcl', (('int', None),) ),
    'advapi32.isvalidsecuritydescriptor':( 'int', None, 'stdcall', 'advapi32.IsValidSecurityDescriptor', (('int', None),) ),
    'advapi32.isvalidsid':( 'int', None, 'stdcall', 'advapi32.IsValidSid', (('int', None),) ),
    'advapi32.iswellknownsid':( 'int', None, 'stdcall', 'advapi32.IsWellKnownSid', (('int', None), ('int', None)) ),
    'advapi32.lockservicedatabase':( 'int', None, 'stdcall', 'advapi32.LockServiceDatabase', (('int', None),) ),
    'advapi32.logonusera':( 'int', None, 'stdcall', 'advapi32.LogonUserA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.logonuserexa':( 'int', None, 'stdcall', 'advapi32.LogonUserExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.logonuserexexw':( 'int', None, 'stdcall', 'advapi32.LogonUserExExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.logonuserexw':( 'int', None, 'stdcall', 'advapi32.LogonUserExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.logonuserw':( 'int', None, 'stdcall', 'advapi32.LogonUserW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupaccountnamea':( 'int', None, 'stdcall', 'advapi32.LookupAccountNameA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupaccountnamew':( 'int', None, 'stdcall', 'advapi32.LookupAccountNameW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupaccountsida':( 'int', None, 'stdcall', 'advapi32.LookupAccountSidA', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.lookupaccountsidw':( 'int', None, 'stdcall', 'advapi32.LookupAccountSidW', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.lookupprivilegedisplaynamea':( 'int', None, 'stdcall', 'advapi32.LookupPrivilegeDisplayNameA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupprivilegedisplaynamew':( 'int', None, 'stdcall', 'advapi32.LookupPrivilegeDisplayNameW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupprivilegenamea':( 'int', None, 'stdcall', 'advapi32.LookupPrivilegeNameA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupprivilegenamew':( 'int', None, 'stdcall', 'advapi32.LookupPrivilegeNameW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupprivilegevaluea':( 'int', None, 'stdcall', 'advapi32.LookupPrivilegeValueA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupprivilegevaluew':( 'int', None, 'stdcall', 'advapi32.LookupPrivilegeValueW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupsecuritydescriptorpartsa':( 'int', None, 'stdcall', 'advapi32.LookupSecurityDescriptorPartsA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lookupsecuritydescriptorpartsw':( 'int', None, 'stdcall', 'advapi32.LookupSecurityDescriptorPartsW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaaddaccountrights':( 'int', None, 'stdcall', 'advapi32.LsaAddAccountRights', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsaaddprivilegestoaccount':( 'int', None, 'stdcall', 'advapi32.LsaAddPrivilegesToAccount', (('int', None), ('int', None)) ),
    'advapi32.lsaclearauditlog':( 'int', None, 'stdcall', 'advapi32.LsaClearAuditLog', (('int', None),) ),
    'advapi32.lsaclose':( 'int', None, 'stdcall', 'advapi32.LsaClose', (('int', None),) ),
    'advapi32.lsacreateaccount':( 'int', None, 'stdcall', 'advapi32.LsaCreateAccount', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsacreatesecret':( 'int', None, 'stdcall', 'advapi32.LsaCreateSecret', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsacreatetrusteddomain':( 'int', None, 'stdcall', 'advapi32.LsaCreateTrustedDomain', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsacreatetrusteddomainex':( 'int', None, 'stdcall', 'advapi32.LsaCreateTrustedDomainEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsadelete':( 'int', None, 'stdcall', 'advapi32.LsaDelete', (('int', None),) ),
    'advapi32.lsadeletetrusteddomain':( 'int', None, 'stdcall', 'advapi32.LsaDeleteTrustedDomain', (('int', None), ('int', None)) ),
    'advapi32.lsaenumerateaccountrights':( 'int', None, 'stdcall', 'advapi32.LsaEnumerateAccountRights', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaenumerateaccounts':( 'int', None, 'stdcall', 'advapi32.LsaEnumerateAccounts', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaenumerateaccountswithuserright':( 'int', None, 'stdcall', 'advapi32.LsaEnumerateAccountsWithUserRight', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.lsaenumerateprivileges':( 'int', None, 'stdcall', 'advapi32.LsaEnumeratePrivileges', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaenumerateprivilegesofaccount':( 'int', None, 'stdcall', 'advapi32.LsaEnumeratePrivilegesOfAccount', (('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaenumeratetrusteddomains':( 'int', None, 'stdcall', 'advapi32.LsaEnumerateTrustedDomains', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaenumeratetrusteddomainsex':( 'int', None, 'stdcall', 'advapi32.LsaEnumerateTrustedDomainsEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsafreememory':( 'int', None, 'stdcall', 'advapi32.LsaFreeMemory', (('int', None),) ),
    'advapi32.lsagetquotasforaccount':( 'int', None, 'stdcall', 'advapi32.LsaGetQuotasForAccount', (('int', None), ('int', None)) ),
    'advapi32.lsagetremoteusername':( 'int', None, 'stdcall', 'advapi32.LsaGetRemoteUserName', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsagetsystemaccessaccount':( 'int', None, 'stdcall', 'advapi32.LsaGetSystemAccessAccount', (('int', None), ('void *', 'ptr')) ),
    'advapi32.lsagetusername':( 'int', None, 'stdcall', 'advapi32.LsaGetUserName', (('int', None), ('int', None)) ),
    'advapi32.lsaiclookupnames':( 'int', None, 'stdcall', 'advapi32.LsaICLookupNames', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsaiclookupnameswithcreds':( 'int', None, 'stdcall', 'advapi32.LsaICLookupNamesWithCreds', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaiclookupsids':( 'int', None, 'stdcall', 'advapi32.LsaICLookupSids', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsaiclookupsidswithcreds':( 'int', None, 'stdcall', 'advapi32.LsaICLookupSidsWithCreds', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsalookupnames':( 'int', None, 'stdcall', 'advapi32.LsaLookupNames', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsalookupnames2':( 'int', None, 'stdcall', 'advapi32.LsaLookupNames2', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.lsalookupprivilegedisplayname':( 'int', None, 'stdcall', 'advapi32.LsaLookupPrivilegeDisplayName', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsalookupprivilegename':( 'int', None, 'stdcall', 'advapi32.LsaLookupPrivilegeName', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsalookupprivilegevalue':( 'int', None, 'stdcall', 'advapi32.LsaLookupPrivilegeValue', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.lsalookupsids':( 'int', None, 'stdcall', 'advapi32.LsaLookupSids', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsantstatustowinerror':( 'int', None, 'cdecl', 'advapi32.LsaNtStatusToWinError', () ),
    'advapi32.lsaopenaccount':( 'int', None, 'stdcall', 'advapi32.LsaOpenAccount', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaopenpolicy':( 'int', None, 'stdcall', 'advapi32.LsaOpenPolicy', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaopenpolicysce':( 'int', None, 'stdcall', 'advapi32.LsaOpenPolicySce', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaopensecret':( 'int', None, 'stdcall', 'advapi32.LsaOpenSecret', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaopentrusteddomain':( 'int', None, 'stdcall', 'advapi32.LsaOpenTrustedDomain', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaopentrusteddomainbyname':( 'int', None, 'stdcall', 'advapi32.LsaOpenTrustedDomainByName', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaquerydomaininformationpolicy':( 'int', None, 'stdcall', 'advapi32.LsaQueryDomainInformationPolicy', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaqueryforesttrustinformation':( 'int', None, 'stdcall', 'advapi32.LsaQueryForestTrustInformation', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaqueryinfotrusteddomain':( 'int', None, 'stdcall', 'advapi32.LsaQueryInfoTrustedDomain', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaqueryinformationpolicy':( 'int', None, 'stdcall', 'advapi32.LsaQueryInformationPolicy', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.lsaquerysecret':( 'int', None, 'stdcall', 'advapi32.LsaQuerySecret', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsaquerysecurityobject':( 'int', None, 'stdcall', 'advapi32.LsaQuerySecurityObject', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaquerytrusteddomaininfo':( 'int', None, 'stdcall', 'advapi32.LsaQueryTrustedDomainInfo', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaquerytrusteddomaininfobyname':( 'int', None, 'stdcall', 'advapi32.LsaQueryTrustedDomainInfoByName', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaremoveaccountrights':( 'int', None, 'stdcall', 'advapi32.LsaRemoveAccountRights', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.lsaremoveprivilegesfromaccount':( 'int', None, 'stdcall', 'advapi32.LsaRemovePrivilegesFromAccount', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsaretrieveprivatedata':( 'int', None, 'stdcall', 'advapi32.LsaRetrievePrivateData', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.lsasetdomaininformationpolicy':( 'int', None, 'stdcall', 'advapi32.LsaSetDomainInformationPolicy', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasetforesttrustinformation':( 'int', None, 'stdcall', 'advapi32.LsaSetForestTrustInformation', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasetinformationpolicy':( 'int', None, 'stdcall', 'advapi32.LsaSetInformationPolicy', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasetinformationtrusteddomain':( 'int', None, 'stdcall', 'advapi32.LsaSetInformationTrustedDomain', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasetquotasforaccount':( 'int', None, 'stdcall', 'advapi32.LsaSetQuotasForAccount', (('int', None), ('int', None)) ),
    'advapi32.lsasetsecret':( 'int', None, 'stdcall', 'advapi32.LsaSetSecret', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasetsecurityobject':( 'int', None, 'stdcall', 'advapi32.LsaSetSecurityObject', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasetsystemaccessaccount':( 'int', None, 'stdcall', 'advapi32.LsaSetSystemAccessAccount', (('int', None), ('int', None)) ),
    'advapi32.lsasettrusteddomaininfobyname':( 'int', None, 'stdcall', 'advapi32.LsaSetTrustedDomainInfoByName', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsasettrusteddomaininformation':( 'int', None, 'stdcall', 'advapi32.LsaSetTrustedDomainInformation', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.lsastoreprivatedata':( 'int', None, 'stdcall', 'advapi32.LsaStorePrivateData', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.md4final':( 'int', None, 'stdcall', 'advapi32.MD4Final', (('void *', 'ptr'),) ),
    'advapi32.md4init':( 'int', None, 'stdcall', 'advapi32.MD4Init', (('void *', 'ptr'),) ),
    'advapi32.md4update':( 'int', None, 'stdcall', 'advapi32.MD4Update', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.md5final':( 'int', None, 'stdcall', 'advapi32.MD5Final', (('void *', 'ptr'),) ),
    'advapi32.md5init':( 'int', None, 'stdcall', 'advapi32.MD5Init', (('void *', 'ptr'),) ),
    'advapi32.md5update':( 'int', None, 'stdcall', 'advapi32.MD5Update', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.mschapsrvchangepassword':( 'int', None, 'stdcall', 'advapi32.MSChapSrvChangePassword', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.mschapsrvchangepassword2':( 'int', None, 'stdcall', 'advapi32.MSChapSrvChangePassword2', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.makeabsolutesd':( 'int', None, 'stdcall', 'advapi32.MakeAbsoluteSD', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.makeabsolutesd2':( 'int', None, 'stdcall', 'advapi32.MakeAbsoluteSD2', (('int', None), ('int', None)) ),
    'advapi32.makeselfrelativesd':( 'int', None, 'stdcall', 'advapi32.MakeSelfRelativeSD', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.mapgenericmask':( 'int', None, 'cdecl', 'advapi32.MapGenericMask', () ),
    'advapi32.notifybootconfigstatus':( 'int', None, 'stdcall', 'advapi32.NotifyBootConfigStatus', (('int', None),) ),
    'advapi32.notifychangeeventlog':( 'int', None, 'stdcall', 'advapi32.NotifyChangeEventLog', (('int', None), ('int', None)) ),
    'advapi32.objectcloseauditalarma':( 'int', None, 'stdcall', 'advapi32.ObjectCloseAuditAlarmA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectcloseauditalarmw':( 'int', None, 'stdcall', 'advapi32.ObjectCloseAuditAlarmW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectdeleteauditalarma':( 'int', None, 'stdcall', 'advapi32.ObjectDeleteAuditAlarmA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectdeleteauditalarmw':( 'int', None, 'stdcall', 'advapi32.ObjectDeleteAuditAlarmW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectopenauditalarma':( 'int', None, 'stdcall', 'advapi32.ObjectOpenAuditAlarmA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectopenauditalarmw':( 'int', None, 'stdcall', 'advapi32.ObjectOpenAuditAlarmW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectprivilegeauditalarma':( 'int', None, 'stdcall', 'advapi32.ObjectPrivilegeAuditAlarmA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.objectprivilegeauditalarmw':( 'int', None, 'stdcall', 'advapi32.ObjectPrivilegeAuditAlarmW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.openbackupeventloga':( 'int', None, 'stdcall', 'advapi32.OpenBackupEventLogA', (('int', None), ('int', None)) ),
    'advapi32.openbackupeventlogw':( 'int', None, 'stdcall', 'advapi32.OpenBackupEventLogW', (('int', None), ('int', None)) ),
    'advapi32.openencryptedfilerawa':( 'int', None, 'stdcall', 'advapi32.OpenEncryptedFileRawA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.openencryptedfileraww':( 'int', None, 'stdcall', 'advapi32.OpenEncryptedFileRawW', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.openeventloga':( 'int', None, 'stdcall', 'advapi32.OpenEventLogA', (('int', None), ('int', None)) ),
    'advapi32.openeventlogw':( 'int', None, 'stdcall', 'advapi32.OpenEventLogW', (('int', None), ('int', None)) ),
    'advapi32.openprocesstoken':( 'int', None, 'stdcall', 'advapi32.OpenProcessToken', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.openscmanagera':( 'int', None, 'stdcall', 'advapi32.OpenSCManagerA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.openscmanagerw':( 'int', None, 'stdcall', 'advapi32.OpenSCManagerW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.openservicea':( 'int', None, 'stdcall', 'advapi32.OpenServiceA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.openservicew':( 'int', None, 'stdcall', 'advapi32.OpenServiceW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.openthreadtoken':( 'int', None, 'stdcall', 'advapi32.OpenThreadToken', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.opentracea':( 'int', None, 'stdcall', 'advapi32.OpenTraceA', (('int', None),) ),
    'advapi32.opentracew':( 'int', None, 'stdcall', 'advapi32.OpenTraceW', (('int', None),) ),
    'advapi32.privilegecheck':( 'int', None, 'stdcall', 'advapi32.PrivilegeCheck', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.privilegedserviceauditalarma':( 'int', None, 'stdcall', 'advapi32.PrivilegedServiceAuditAlarmA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.privilegedserviceauditalarmw':( 'int', None, 'stdcall', 'advapi32.PrivilegedServiceAuditAlarmW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.processidletasks':( 'int', None, 'cdecl', 'advapi32.ProcessIdleTasks', () ),
    'advapi32.processtrace':( 'int', None, 'stdcall', 'advapi32.ProcessTrace', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryalltracesa':( 'int', None, 'stdcall', 'advapi32.QueryAllTracesA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryalltracesw':( 'int', None, 'stdcall', 'advapi32.QueryAllTracesW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryrecoveryagentsonencryptedfile':( 'int', None, 'stdcall', 'advapi32.QueryRecoveryAgentsOnEncryptedFile', (('int', None), ('int', None)) ),
    'advapi32.queryserviceconfig2a':( 'int', None, 'stdcall', 'advapi32.QueryServiceConfig2A', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryserviceconfig2w':( 'int', None, 'stdcall', 'advapi32.QueryServiceConfig2W', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryserviceconfiga':( 'int', None, 'stdcall', 'advapi32.QueryServiceConfigA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryserviceconfigw':( 'int', None, 'stdcall', 'advapi32.QueryServiceConfigW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryservicelockstatusa':( 'int', None, 'stdcall', 'advapi32.QueryServiceLockStatusA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryservicelockstatusw':( 'int', None, 'stdcall', 'advapi32.QueryServiceLockStatusW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryserviceobjectsecurity':( 'int', None, 'stdcall', 'advapi32.QueryServiceObjectSecurity', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.queryservicestatus':( 'int', None, 'stdcall', 'advapi32.QueryServiceStatus', (('int', None), ('void *', 'ptr')) ),
    'advapi32.queryservicestatusex':( 'int', None, 'stdcall', 'advapi32.QueryServiceStatusEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.querytracea':( 'int', None, 'stdcall', 'advapi32.QueryTraceA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.querytracew':( 'int', None, 'stdcall', 'advapi32.QueryTraceW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.queryusersonencryptedfile':( 'int', None, 'stdcall', 'advapi32.QueryUsersOnEncryptedFile', (('int', None), ('int', None)) ),
    'advapi32.querywindows31filesmigration':( 'int', None, 'stdcall', 'advapi32.QueryWindows31FilesMigration', (('int', None),) ),
    'advapi32.readencryptedfileraw':( 'int', None, 'cdecl', 'advapi32.ReadEncryptedFileRaw', () ),
    'advapi32.readeventloga':( 'int', None, 'stdcall', 'advapi32.ReadEventLogA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.readeventlogw':( 'int', None, 'stdcall', 'advapi32.ReadEventLogW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regclosekey':( 'int', None, 'stdcall', 'advapi32.RegCloseKey', (('int', None),) ),
    'advapi32.regconnectregistrya':( 'int', None, 'stdcall', 'advapi32.RegConnectRegistryA', ( ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regconnectregistryw':( 'int', None, 'stdcall', 'advapi32.RegConnectRegistryW', ( ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.regcreatekeya':( 'int', None, 'stdcall', 'advapi32.RegCreateKeyA', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.regcreatekeyexa':( 'int', None, 'stdcall', 'advapi32.RegCreateKeyExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regcreatekeyexw':( 'int', None, 'stdcall', 'advapi32.RegCreateKeyExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regcreatekeyw':( 'int', None, 'stdcall', 'advapi32.RegCreateKeyW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regdeletekeya':( 'int', None, 'stdcall', 'advapi32.RegDeleteKeyA', (('int', None), ('int', None)) ),
    'advapi32.regdeletekeyw':( 'int', None, 'stdcall', 'advapi32.RegDeleteKeyW', (('int', None), ('int', None)) ),
    'advapi32.regdeletevaluea':( 'int', None, 'stdcall', 'advapi32.RegDeleteValueA', (('int', None), ('int', None)) ),
    'advapi32.regdeletevaluew':( 'int', None, 'stdcall', 'advapi32.RegDeleteValueW', (('int', None), ('int', None)) ),
    'advapi32.regdisablepredefinedcache':( 'int', None, 'cdecl', 'advapi32.RegDisablePredefinedCache', () ),
    'advapi32.regdisablepredefinedcacheex':( 'int', None, 'cdecl', 'advapi32.RegDisablePredefinedCacheEx', () ),
    'advapi32.regenumkeya':( 'int', None, 'stdcall', 'advapi32.RegEnumKeyA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regenumkeyexa':( 'int', None, 'stdcall', 'advapi32.RegEnumKeyExA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regenumkeyexw':( 'int', None, 'stdcall', 'advapi32.RegEnumKeyExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regenumkeyw':( 'int', None, 'stdcall', 'advapi32.RegEnumKeyW', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.regenumvaluea':( 'int', None, 'stdcall', 'advapi32.RegEnumValueA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regenumvaluew':( 'int', None, 'stdcall', 'advapi32.RegEnumValueW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regflushkey':( 'int', None, 'stdcall', 'advapi32.RegFlushKey', (('int', None),) ),
    'advapi32.reggetkeysecurity':( 'int', None, 'stdcall', 'advapi32.RegGetKeySecurity', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regloadkeya':( 'int', None, 'stdcall', 'advapi32.RegLoadKeyA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regloadkeyw':( 'int', None, 'stdcall', 'advapi32.RegLoadKeyW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regnotifychangekeyvalue':( 'int', None, 'stdcall', 'advapi32.RegNotifyChangeKeyValue', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regopencurrentuser':( 'int', None, 'stdcall', 'advapi32.RegOpenCurrentUser', (('int', None), ('void *', 'ptr')) ),
    'advapi32.regopenkeya':( 'int', None, 'stdcall', 'advapi32.RegOpenKeyA', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.regopenkeyexa':( 'int', None, 'stdcall', 'advapi32.RegOpenKeyExA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.regopenkeyexw':( 'int', None, 'stdcall', 'advapi32.RegOpenKeyExW', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.regopenkeyw':( 'int', None, 'stdcall', 'advapi32.RegOpenKeyW', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regopenuserclassesroot':( 'int', None, 'stdcall', 'advapi32.RegOpenUserClassesRoot', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regoverridepredefkey':( 'int', None, 'stdcall', 'advapi32.RegOverridePredefKey', (('int', None), ('int', None)) ),
    'advapi32.regqueryinfokeya':( 'int', None, 'stdcall', 'advapi32.RegQueryInfoKeyA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.regqueryinfokeyw':( 'int', None, 'stdcall', 'advapi32.RegQueryInfoKeyW', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regquerymultiplevaluesa':( 'int', None, 'stdcall', 'advapi32.RegQueryMultipleValuesA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regquerymultiplevaluesw':( 'int', None, 'stdcall', 'advapi32.RegQueryMultipleValuesW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regqueryvaluea':( 'int', None, 'stdcall', 'advapi32.RegQueryValueA', (('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regqueryvalueexa':( 'int', None, 'stdcall', 'advapi32.RegQueryValueExA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regqueryvalueexw':( 'int', None, 'stdcall', 'advapi32.RegQueryValueExW', (('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regqueryvaluew':( 'int', None, 'stdcall', 'advapi32.RegQueryValueW', (('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.regreplacekeya':( 'int', None, 'stdcall', 'advapi32.RegReplaceKeyA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regreplacekeyw':( 'int', None, 'stdcall', 'advapi32.RegReplaceKeyW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regrestorekeya':( 'int', None, 'stdcall', 'advapi32.RegRestoreKeyA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regrestorekeyw':( 'int', None, 'stdcall', 'advapi32.RegRestoreKeyW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsavekeya':( 'int', None, 'stdcall', 'advapi32.RegSaveKeyA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsavekeyexa':( 'int', None, 'stdcall', 'advapi32.RegSaveKeyExA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsavekeyexw':( 'int', None, 'stdcall', 'advapi32.RegSaveKeyExW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsavekeyw':( 'int', None, 'stdcall', 'advapi32.RegSaveKeyW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsetkeysecurity':( 'int', None, 'stdcall', 'advapi32.RegSetKeySecurity', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsetvaluea':( 'int', None, 'stdcall', 'advapi32.RegSetValueA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsetvalueexa':( 'int', None, 'stdcall', 'advapi32.RegSetValueExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.regsetvalueexw':( 'int', None, 'stdcall', 'advapi32.RegSetValueExW', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.regsetvaluew':( 'int', None, 'stdcall', 'advapi32.RegSetValueW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.regunloadkeya':( 'int', None, 'stdcall', 'advapi32.RegUnLoadKeyA', (('int', None), ('int', None)) ),
    'advapi32.regunloadkeyw':( 'int', None, 'stdcall', 'advapi32.RegUnLoadKeyW', (('int', None), ('int', None)) ),
    'advapi32.registereventsourcea':( 'int', None, 'stdcall', 'advapi32.RegisterEventSourceA', (('int', None), ('int', None)) ),
    'advapi32.registereventsourcew':( 'int', None, 'stdcall', 'advapi32.RegisterEventSourceW', (('int', None), ('int', None)) ),
    'advapi32.registeridletask':( 'int', None, 'stdcall', 'advapi32.RegisterIdleTask', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.registerservicectrlhandlera':( 'int', None, 'stdcall', 'advapi32.RegisterServiceCtrlHandlerA', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.registerservicectrlhandlerexa':( 'int', None, 'stdcall', 'advapi32.RegisterServiceCtrlHandlerExA', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.registerservicectrlhandlerexw':( 'int', None, 'stdcall', 'advapi32.RegisterServiceCtrlHandlerExW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.registerservicectrlhandlerw':( 'int', None, 'stdcall', 'advapi32.RegisterServiceCtrlHandlerW', (('int', None), ('int', None)) ),
    'advapi32.registertraceguidsa':( 'int', None, 'stdcall', 'advapi32.RegisterTraceGuidsA', (('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.registertraceguidsw':( 'int', None, 'stdcall', 'advapi32.RegisterTraceGuidsW', (('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.removetracecallback':( 'int', None, 'stdcall', 'advapi32.RemoveTraceCallback', (('int', None),) ),
    'advapi32.removeusersfromencryptedfile':( 'int', None, 'stdcall', 'advapi32.RemoveUsersFromEncryptedFile', (('int', None), ('int', None)) ),
    'advapi32.reporteventa':( 'int', None, 'stdcall', 'advapi32.ReportEventA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.reporteventw':( 'int', None, 'stdcall', 'advapi32.ReportEventW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.reverttoself':( 'int', None, 'cdecl', 'advapi32.RevertToSelf', () ),
    'advapi32.safercloselevel':( 'int', None, 'stdcall', 'advapi32.SaferCloseLevel', (('int', None),) ),
    'advapi32.safercomputetokenfromlevel':( 'int', None, 'stdcall', 'advapi32.SaferComputeTokenFromLevel', ( ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.safercreatelevel':( 'int', None, 'stdcall', 'advapi32.SaferCreateLevel', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.safergetlevelinformation':( 'int', None, 'stdcall', 'advapi32.SaferGetLevelInformation', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.safergetpolicyinformation':( 'int', None, 'stdcall', 'advapi32.SaferGetPolicyInformation', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.saferidentifylevel':( 'int', None, 'stdcall', 'advapi32.SaferIdentifyLevel', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.saferrecordeventlogentry':( 'int', None, 'stdcall', 'advapi32.SaferRecordEventLogEntry', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.safersetlevelinformation':( 'int', None, 'stdcall', 'advapi32.SaferSetLevelInformation', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.safersetpolicyinformation':( 'int', None, 'stdcall', 'advapi32.SaferSetPolicyInformation', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.saferichangeregistryscope':( 'int', None, 'stdcall', 'advapi32.SaferiChangeRegistryScope', ( ('int', None), ('int', None)) ),
    'advapi32.safericomparetokenlevels':( 'int', None, 'stdcall', 'advapi32.SaferiCompareTokenLevels', ( ('int', None), ('int', None), ('int', None)) ),
    'advapi32.saferiisexecutablefiletype':( 'int', None, 'stdcall', 'advapi32.SaferiIsExecutableFileType', (('int', None), ('DWORD', None)) ),
    'advapi32.saferipopulatedefaultsinregistry':( 'int', None, 'stdcall', 'advapi32.SaferiPopulateDefaultsInRegistry', (('int', None), ('int', None)) ),
    'advapi32.saferirecordeventlogentry':( 'int', None, 'stdcall', 'advapi32.SaferiRecordEventLogEntry', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.saferireplaceprocessthreadtokens':( 'int', None, 'stdcall', 'advapi32.SaferiReplaceProcessThreadTokens', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.saferisearchmatchinghashrules':( 'int', None, 'stdcall', 'advapi32.SaferiSearchMatchingHashRules', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setaclinformation':( 'int', None, 'stdcall', 'advapi32.SetAclInformation', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setentriesinaccesslista':( 'int', None, 'stdcall', 'advapi32.SetEntriesInAccessListA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.setentriesinaccesslistw':( 'int', None, 'stdcall', 'advapi32.SetEntriesInAccessListW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setentriesinacla':( 'int', None, 'stdcall', 'advapi32.SetEntriesInAclA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setentriesinaclw':( 'int', None, 'stdcall', 'advapi32.SetEntriesInAclW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.setentriesinauditlista':( 'int', None, 'stdcall', 'advapi32.SetEntriesInAuditListA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.setentriesinauditlistw':( 'int', None, 'stdcall', 'advapi32.SetEntriesInAuditListW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setfilesecuritya':( 'int', None, 'stdcall', 'advapi32.SetFileSecurityA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.setfilesecurityw':( 'int', None, 'stdcall', 'advapi32.SetFileSecurityW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.setinformationcodeauthzlevelw':( 'int', None, 'stdcall', 'advapi32.SetInformationCodeAuthzLevelW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setinformationcodeauthzpolicyw':( 'int', None, 'stdcall', 'advapi32.SetInformationCodeAuthzPolicyW', ( ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setkernelobjectsecurity':( 'int', None, 'stdcall', 'advapi32.SetKernelObjectSecurity', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.setnamedsecurityinfoa':( 'int', None, 'stdcall', 'advapi32.SetNamedSecurityInfoA', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setnamedsecurityinfoexa':( 'int', None, 'stdcall', 'advapi32.SetNamedSecurityInfoExA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setnamedsecurityinfoexw':( 'int', None, 'stdcall', 'advapi32.SetNamedSecurityInfoExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setnamedsecurityinfow':( 'int', None, 'stdcall', 'advapi32.SetNamedSecurityInfoW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setprivateobjectsecurity':( 'int', None, 'stdcall', 'advapi32.SetPrivateObjectSecurity', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setprivateobjectsecurityex':( 'int', None, 'stdcall', 'advapi32.SetPrivateObjectSecurityEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setsecuritydescriptorcontrol':( 'int', None, 'stdcall', 'advapi32.SetSecurityDescriptorControl', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.setsecuritydescriptordacl':( 'int', None, 'stdcall', 'advapi32.SetSecurityDescriptorDacl', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setsecuritydescriptorgroup':( 'int', None, 'stdcall', 'advapi32.SetSecurityDescriptorGroup', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.setsecuritydescriptorowner':( 'int', None, 'stdcall', 'advapi32.SetSecurityDescriptorOwner', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.setsecuritydescriptorrmcontrol':( 'int', None, 'stdcall', 'advapi32.SetSecurityDescriptorRMControl', (('int', None), ('int', None)) ),
    'advapi32.setsecuritydescriptorsacl':( 'int', None, 'stdcall', 'advapi32.SetSecurityDescriptorSacl', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setsecurityinfo':( 'int', None, 'stdcall', 'advapi32.SetSecurityInfo', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setsecurityinfoexa':( 'int', None, 'stdcall', 'advapi32.SetSecurityInfoExA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setsecurityinfoexw':( 'int', None, 'stdcall', 'advapi32.SetSecurityInfoExW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setservicebits':( 'int', None, 'stdcall', 'advapi32.SetServiceBits', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.setserviceobjectsecurity':( 'int', None, 'stdcall', 'advapi32.SetServiceObjectSecurity', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.setservicestatus':( 'int', None, 'stdcall', 'advapi32.SetServiceStatus', (('int', None), ('int', None)) ),
    'advapi32.setthreadtoken':( 'int', None, 'stdcall', 'advapi32.SetThreadToken', (('int', None), ('int', None)) ),
    'advapi32.settokeninformation':( 'int', None, 'stdcall', 'advapi32.SetTokenInformation', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.settracecallback':( 'int', None, 'stdcall', 'advapi32.SetTraceCallback', (('int', None), ('int', None)) ),
    'advapi32.setuserfileencryptionkey':( 'int', None, 'stdcall', 'advapi32.SetUserFileEncryptionKey', (('int', None),) ),
    'advapi32.startservicea':( 'int', None, 'stdcall', 'advapi32.StartServiceA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.startservicectrldispatchera':( 'int', None, 'stdcall', 'advapi32.StartServiceCtrlDispatcherA', (('int', None),) ),
    'advapi32.startservicectrldispatcherw':( 'int', None, 'stdcall', 'advapi32.StartServiceCtrlDispatcherW', (('int', None),) ),
    'advapi32.startservicew':( 'int', None, 'stdcall', 'advapi32.StartServiceW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.starttracea':( 'int', None, 'stdcall', 'advapi32.StartTraceA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.starttracew':( 'int', None, 'stdcall', 'advapi32.StartTraceW', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'advapi32.stoptracea':( 'int', None, 'stdcall', 'advapi32.StopTraceA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.stoptracew':( 'int', None, 'stdcall', 'advapi32.StopTraceW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.synchronizewindows31filesandwindowsntregistry':( 'int', None, 'stdcall', 'advapi32.SynchronizeWindows31FilesAndWindowsNTRegistry', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction001':( 'int', None, 'stdcall', 'advapi32.SystemFunction001', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction002':( 'int', None, 'stdcall', 'advapi32.SystemFunction002', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.systemfunction003':( 'int', None, 'stdcall', 'advapi32.SystemFunction003', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction004':( 'int', None, 'stdcall', 'advapi32.SystemFunction004', (('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.systemfunction005':( 'int', None, 'stdcall', 'advapi32.SystemFunction005', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.systemfunction006':( 'int', None, 'stdcall', 'advapi32.SystemFunction006', (('int', None), ('int', None)) ),
    'advapi32.systemfunction007':( 'int', None, 'stdcall', 'advapi32.SystemFunction007', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction008':( 'int', None, 'stdcall', 'advapi32.SystemFunction008', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction009':( 'int', None, 'stdcall', 'advapi32.SystemFunction009', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction010':( 'int', None, 'stdcall', 'advapi32.SystemFunction010', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction011':( 'int', None, 'stdcall', 'advapi32.SystemFunction011', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction012':( 'int', None, 'stdcall', 'advapi32.SystemFunction012', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction013':( 'int', None, 'stdcall', 'advapi32.SystemFunction013', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction014':( 'int', None, 'stdcall', 'advapi32.SystemFunction014', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction015':( 'int', None, 'stdcall', 'advapi32.SystemFunction015', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction016':( 'int', None, 'stdcall', 'advapi32.SystemFunction016', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction017':( 'int', None, 'stdcall', 'advapi32.SystemFunction017', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction018':( 'int', None, 'stdcall', 'advapi32.SystemFunction018', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction019':( 'int', None, 'stdcall', 'advapi32.SystemFunction019', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction020':( 'int', None, 'stdcall', 'advapi32.SystemFunction020', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction021':( 'int', None, 'stdcall', 'advapi32.SystemFunction021', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction022':( 'int', None, 'stdcall', 'advapi32.SystemFunction022', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction023':( 'int', None, 'stdcall', 'advapi32.SystemFunction023', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction024':( 'int', None, 'stdcall', 'advapi32.SystemFunction024', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction025':( 'int', None, 'stdcall', 'advapi32.SystemFunction025', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction026':( 'int', None, 'stdcall', 'advapi32.SystemFunction026', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction027':( 'int', None, 'stdcall', 'advapi32.SystemFunction027', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.systemfunction028':( 'int', None, 'stdcall', 'advapi32.SystemFunction028', (('int', None), ('void *', 'ptr')) ),
    'advapi32.systemfunction029':( 'int', None, 'stdcall', 'advapi32.SystemFunction029', (('int', None), ('int', None)) ),
    'advapi32.systemfunction030':( 'int', None, 'stdcall', 'advapi32.SystemFunction030', (('int', None), ('int', None)) ),
    'advapi32.systemfunction031':( 'int', None, 'stdcall', 'advapi32.SystemFunction031', (('int', None), ('int', None)) ),
    'advapi32.systemfunction032':( 'int', None, 'stdcall', 'advapi32.SystemFunction032', (('int', None), ('int', None)) ),
    'advapi32.systemfunction033':( 'int', None, 'stdcall', 'advapi32.SystemFunction033', (('int', None), ('int', None)) ),
    'advapi32.systemfunction034':( 'int', None, 'stdcall', 'advapi32.SystemFunction034', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction035':( 'int', None, 'stdcall', 'advapi32.SystemFunction035', (('int', None),) ),
    'advapi32.systemfunction036':( 'int', None, 'stdcall', 'advapi32.SystemFunction036', (('void *', 'ptr'), ('int', None)) ),
    'advapi32.systemfunction040':( 'int', None, 'stdcall', 'advapi32.SystemFunction040', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'advapi32.systemfunction041':( 'int', None, 'stdcall', 'advapi32.SystemFunction041', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.traceevent':( 'int', None, 'stdcall', 'advapi32.TraceEvent', (('int', None), ('int', None), ('void *', 'obj')) ),
    'advapi32.traceeventinstance':( 'int', None, 'stdcall', 'advapi32.TraceEventInstance', (('int', None), ('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'advapi32.tracemessage':( 'int', None, 'cdecl', 'advapi32.TraceMessage', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.tracemessageva':( 'int', None, 'stdcall', 'advapi32.TraceMessageVa', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.treeresetnamedsecurityinfoa':( 'int', None, 'stdcall', 'advapi32.TreeResetNamedSecurityInfoA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.treeresetnamedsecurityinfow':( 'int', None, 'stdcall', 'advapi32.TreeResetNamedSecurityInfoW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.trusteeaccesstoobjecta':( 'int', None, 'stdcall', 'advapi32.TrusteeAccessToObjectA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.trusteeaccesstoobjectw':( 'int', None, 'stdcall', 'advapi32.TrusteeAccessToObjectW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.uninstallapplication':( 'int', None, 'stdcall', 'advapi32.UninstallApplication', (('int', None), ('int', None)) ),
    'advapi32.unlockservicedatabase':( 'int', None, 'stdcall', 'advapi32.UnlockServiceDatabase', (('int', None),) ),
    'advapi32.unregisteridletask':( 'int', None, 'stdcall', 'advapi32.UnregisterIdleTask', (('int', None), ('HANDLE', None), ('HANDLE', None)) ),
    'advapi32.unregistertraceguids':( 'int', None, 'stdcall', 'advapi32.UnregisterTraceGuids', (('int', None), ('int', None)) ),
    'advapi32.updatetracea':( 'int', None, 'stdcall', 'advapi32.UpdateTraceA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.updatetracew':( 'int', None, 'stdcall', 'advapi32.UpdateTraceW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wdmwmiservicemain':( 'int', None, 'stdcall', 'advapi32.WdmWmiServiceMain', (('int', None), ('int', None)) ),
    'advapi32.wmicloseblock':( 'int', None, 'stdcall', 'advapi32.WmiCloseBlock', (('HANDLE', None),) ),
    'advapi32.wmiclosetracewithcursor':( 'int', None, 'stdcall', 'advapi32.WmiCloseTraceWithCursor', (('int', None),) ),
    'advapi32.wmiconverttimestamp':( 'int', None, 'stdcall', 'advapi32.WmiConvertTimestamp', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmidevinsttoinstancenamea':( 'int', None, 'stdcall', 'advapi32.WmiDevInstToInstanceNameA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmidevinsttoinstancenamew':( 'int', None, 'stdcall', 'advapi32.WmiDevInstToInstanceNameW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmienumerateguids':( 'int', None, 'stdcall', 'advapi32.WmiEnumerateGuids', (('int', None), ('int', None)) ),
    'advapi32.wmiexecutemethoda':( 'int', None, 'stdcall', 'advapi32.WmiExecuteMethodA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmiexecutemethodw':( 'int', None, 'stdcall', 'advapi32.WmiExecuteMethodW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmifilehandletoinstancenamea':( 'int', None, 'stdcall', 'advapi32.WmiFileHandleToInstanceNameA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmifilehandletoinstancenamew':( 'int', None, 'stdcall', 'advapi32.WmiFileHandleToInstanceNameW', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'advapi32.wmifreebuffer':( 'int', None, 'stdcall', 'advapi32.WmiFreeBuffer', (('void *', 'ptr'),) ),
    'advapi32.wmigetfirsttraceoffset':( 'int', None, 'stdcall', 'advapi32.WmiGetFirstTraceOffset', (('int', None),) ),
    'advapi32.wmigetnextevent':( 'int', None, 'stdcall', 'advapi32.WmiGetNextEvent', (('int', None),) ),
    'advapi32.wmigettraceheader':( 'int', None, 'stdcall', 'advapi32.WmiGetTraceHeader', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.wmimofenumerateresourcesa':( 'int', None, 'stdcall', 'advapi32.WmiMofEnumerateResourcesA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmimofenumerateresourcesw':( 'int', None, 'stdcall', 'advapi32.WmiMofEnumerateResourcesW', (('int', None), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'advapi32.wminotificationregistrationa':( 'int', None, 'stdcall', 'advapi32.WmiNotificationRegistrationA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wminotificationregistrationw':( 'int', None, 'stdcall', 'advapi32.WmiNotificationRegistrationW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmiopenblock':( 'int', None, 'stdcall', 'advapi32.WmiOpenBlock', (('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.wmiopentracewithcursor':( 'int', None, 'stdcall', 'advapi32.WmiOpenTraceWithCursor', (('void *', 'ptr'),) ),
    'advapi32.wmiparsetraceevent':( 'int', None, 'stdcall', 'advapi32.WmiParseTraceEvent', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmiqueryalldataa':( 'int', None, 'stdcall', 'advapi32.WmiQueryAllDataA', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmiqueryalldatamultiplea':( 'int', None, 'stdcall', 'advapi32.WmiQueryAllDataMultipleA', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.wmiqueryalldatamultiplew':( 'int', None, 'stdcall', 'advapi32.WmiQueryAllDataMultipleW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.wmiqueryalldataw':( 'int', None, 'stdcall', 'advapi32.WmiQueryAllDataW', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmiqueryguidinformation':( 'int', None, 'stdcall', 'advapi32.WmiQueryGuidInformation', (('int', None), ('int', None)) ),
    'advapi32.wmiquerysingleinstancea':( 'int', None, 'stdcall', 'advapi32.WmiQuerySingleInstanceA', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmiquerysingleinstancemultiplea':( 'int', None, 'stdcall', 'advapi32.WmiQuerySingleInstanceMultipleA', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.wmiquerysingleinstancemultiplew':( 'int', None, 'stdcall', 'advapi32.WmiQuerySingleInstanceMultipleW', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'advapi32.wmiquerysingleinstancew':( 'int', None, 'stdcall', 'advapi32.WmiQuerySingleInstanceW', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmireceivenotificationsa':( 'int', None, 'stdcall', 'advapi32.WmiReceiveNotificationsA', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'advapi32.wmireceivenotificationsw':( 'int', None, 'stdcall', 'advapi32.WmiReceiveNotificationsW', (('int', None), ('int', None), ('void *', 'funcptr'), ('int', None)) ),
    'advapi32.wmisetsingleinstancea':( 'int', None, 'stdcall', 'advapi32.WmiSetSingleInstanceA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmisetsingleinstancew':( 'int', None, 'stdcall', 'advapi32.WmiSetSingleInstanceW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmisetsingleitema':( 'int', None, 'stdcall', 'advapi32.WmiSetSingleItemA', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wmisetsingleitemw':( 'int', None, 'stdcall', 'advapi32.WmiSetSingleItemW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'advapi32.wow64win32apientry':( 'int', None, 'stdcall', 'advapi32.Wow64Win32ApiEntry', (('int', None), ('int', None), ('int', None)) ),
    'advapi32.writeencryptedfileraw':( 'int', None, 'cdecl', 'advapi32.WriteEncryptedFileRaw', () ),
    }



'''
Symboliks algebraic substitution helpers (SubStates)

Users of this API probably want the following two classes:

sset - Produces a given set of values ( ie. [1,3,33,9384] )
srange - Iterates similar to range (ie. max,min,inc )

Once instanciated, any SubState may be multiplied or added to
others to create the implied set of states.

For example, the following little example:
=======================================
    x = srange('arg0', 3)
    y = sset('arg1', [1,9,13])

    print('added:')
    for i in (x+y):
        print repr(i)

    print('multiplied:')
    for i in (x*y):
        print repr(i)
=======================================

Produces the following output:
=======================================
added:
{'arg0': 0, 'arg1': 1}
{'arg0': 1, 'arg1': 1}
{'arg0': 2, 'arg1': 1}
{'arg0': 0, 'arg1': 1}
{'arg0': 0, 'arg1': 9}
{'arg0': 0, 'arg1': 13}
multiplied:
{'arg0': 0, 'arg1': 1}
{'arg0': 1, 'arg1': 1}
{'arg0': 2, 'arg1': 1}
{'arg0': 0, 'arg1': 9}
{'arg0': 1, 'arg1': 9}
{'arg0': 2, 'arg1': 9}
{'arg0': 0, 'arg1': 13}
{'arg0': 1, 'arg1': 13}
{'arg0': 2, 'arg1': 13}
=======================================
'''


class SubState:
    '''
    The base SubState class designed to help out creating
    iterable combinatorc states.
    '''
    def __init__(self, iname, icount):
        self.iname = iname
        self.icount = icount

    def getCombState(self, i, d=None):
        if d is None:
            d = {}
        d[self.iname] = self[i]
        return d

    def __iter__(self):
        for i in range(len(self)):
            yield self.getCombState(i)

    def __getslice__(self, x, y):
        for i in range(x, y+1):
            yield self.getCombState(i)

    def __add__(self, x):
        return AddSubState(self, x)

    def __mul__(self, x):
        return MultSubState(self, x)

    def __len__(self):
        return self.icount

    def __getitem__(self, i):
        raise Exception('SubState must implement __getitem__!')


class AddSubState(SubState):
    '''
    A combiner which produces the union of the two
    given combiner.
    '''
    def __init__(self, comb1, comb2):
        comb1len = len(comb1)
        comb2len = len(comb2)

        SubState.__init__(self, None, comb1len + comb2len)
        self.comb1 = comb1
        self.comb2 = comb2
        self.comb1len = comb1len
        self.comb2len = comb2len

    def getCombState(self, i, d=None):
        if d is None:
            d = {}

        if i >= self.comb1len:
            c1 = 0
            c2 = i - self.comb1len
            # Do these in this order in case they have
            # two sets for the same var...
            self.comb1.getCombState(c1, d=d)
            self.comb2.getCombState(c2, d=d)
        else:
            c1 = i
            c2 = 0
            # and likewise... ( see above )
            self.comb2.getCombState(c2, d=d)
            self.comb1.getCombState(c1, d=d)

        return d


class MultSubState(SubState):

    def __init__(self, comb1, comb2):
        comb1len = len(comb1)
        comb2len = len(comb2)

        SubState.__init__(self, None, comb1len * comb2len)
        self.comb1 = comb1
        self.comb2 = comb2
        self.comb1len = comb1len
        self.comb2len = comb2len

    def getCombState(self, i, d=None):
        if d is None:
            d = {}

        c2, c1 = divmod(i, self.comb1len)

        self.comb1.getCombState(c1, d=d)
        self.comb2.getCombState(c2, d=d)
        return d


class srange(SubState):
    '''
    A SubState class which produces values over a range similar
    to the python builtin range.

    Example:
        # substitute arg0 from 4 to 29 (inclusive)
        srange('arg0', 30, 4)
    '''
    def __init__(self, iname, imax, imin=0, iinc=1):
        icount = int((imax - imin) / iinc)
        SubState.__init__(self, iname, icount)
        self.imin = imin
        self.imax = imax
        self.iinc = iinc

    def __getitem__(self, i):
        return self.imin + (self.iinc * i)


class sset(SubState):
    '''
    A SubState class which produces values from an
    iterable object (which it must turn into a list).

    Example:
        # substitute arg1 through the values 5,56,90
        sset('arg1', [5,56,90])
    '''
    def __init__(self, iname, items):
        items = list(items)
        SubState.__init__(self, iname, len(items))
        self.combitems = items

    def __getitem__(self, i):
        return self.combitems[i]
